@@ -17,11 +17,13 @@ mod comment;
 mod common;
 mod decl;
 mod expr;
+pub mod flavor;
 mod flow;
 mod jsx;
 mod lit;
 mod module;
 mod object;
 mod pat;
+mod ser;
 mod stmt;
 mod typescript;
